@@ -4,11 +4,11 @@
 import logging
 import gzip
 from ..bouth23 import s, bstream
-try:
+try:                     # pragma: no cover
     from urllib.parse import urlencode
     from urllib.request import Request, urlopen
     from urllib.error import HTTPError, URLError
-except ImportError:
+except ImportError:      # pragma: no cover
     from urllib import urlencode
     from urllib2 import Request, urlopen, HTTPError, URLError
 from .exceptions import ISBNToolsHTTPError, ISBNToolsURLError
@@ -37,11 +37,11 @@ class WEBService(object):
     def _response(self):
         try:
             self.response = urlopen(self._request)
-        except HTTPError as e:
+        except HTTPError as e:  # pragma: no cover
             LOGGER.critical('ISBNToolsHTTPError for %s with code %s',
                             self._url, e.code)
             raise ISBNToolsHTTPError(e.code)
-        except URLError as e:
+        except URLError as e:   # pragma: no cover
             LOGGER.critical('ISBNToolsURLError for %s with reason %s',
                             self._url, e.reason)
             raise ISBNToolsURLError(e.reason)
@@ -55,7 +55,7 @@ class WEBService(object):
             buf = bstream(self.response.read())
             f = gzip.GzipFile(fileobj=buf)
             data = f.read()
-        else:
+        else:                   # pragma: no cover
             data = self.response.read()
         return s(data)
 
