@@ -5,19 +5,15 @@ Registry for metadata services
 
 import imp
 import sys
-from .dev import wcat
-from .dev import goob
-from .dev import merge
-from .dev import isbndb
-from .dev import openl
+from . import wcat
+from . import goob
+from . import merge
 from .exceptions import PluginNotLoadedError
 
 services = {'default': merge.query,
             'wcat': wcat.query,
             'goob': goob.query,
             'merge': merge.query,
-            'isbndb': isbndb.query,
-            'openl': openl.query,
             }
 
 
