@@ -27,6 +27,10 @@ plugins_path = os.path.join(pkg_path, 'contrib/plugins')
 try:
     # read conf file
     conf = configparser.ConfigParser()
+    # read defaults
+    with open(os.path.join(pkg_path, 'isbntools.conf.py'), 'r') as f:
+        conf.readfp(f)
+    # read user options
     if in_virtual():
         conf.read([os.path.join(sys.prefix, 'isbntools.conf')])
     else:
@@ -34,11 +38,12 @@ try:
             conf.read([os.path.join(os.getenv('APPDATA'),
                       'isbntools/isbntools.conf')])
         else:                        # pragma: no cover
-            conf.read(['/etc/isbntools/.isbntools.conf',
-                       '/usr/local/.isbntools.conf',
-                       '/usr/local/bin/.isbntools.conf',
-                      os.path.expanduser('~/.isbntools.conf'),
-                      os.path.expanduser('~/.isbntools/isbntools.conf')])
+            conf.read(['/etc/.isbntools/isbntools.conf',
+                       '/usr/local/isbntools.conf',
+                       '/usr/local/bin/isbntools.conf',
+                       os.path.expanduser('~/.isbntools.conf'),
+                       os.path.expanduser('~/.local/.isbntools/isbntools.conf'),
+                       os.path.expanduser('~/.isbntools/isbntools.conf')])
 
     if conf.has_section('SYS'):
         # get user defined values for timeouts
